summaryrefslogtreecommitdiff
path: root/src/mesa/state_tracker/st_draw.c
diff options
context:
space:
mode:
authorKeith Whitwell <keith@tungstengraphics.com>2007-06-14 18:23:43 +0100
committerKeith Whitwell <keith@tungstengraphics.com>2007-06-14 18:23:43 +0100
commit943964a1e5bad86bdceb0a06d60fb3b302ebce6a (patch)
treea4ed47408b6d7a856b510ae68230d0ba3479071f /src/mesa/state_tracker/st_draw.c
parent6393cda6766b707ef01e925d378239a66d143ae0 (diff)
Rename directories again?!
Some git wierdness going on.
Diffstat (limited to 'src/mesa/state_tracker/st_draw.c')
-rw-r--r--src/mesa/state_tracker/st_draw.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mesa/state_tracker/st_draw.c b/src/mesa/state_tracker/st_draw.c
index 12646402ee..4db8189988 100644
--- a/src/mesa/state_tracker/st_draw.c
+++ b/src/mesa/state_tracker/st_draw.c
@@ -38,7 +38,7 @@
#include "st_context.h"
#include "st_atom.h"
#include "st_draw.h"
-#include "softpipe/sp_context.h"
+#include "pipe/p_context.h"
/*
* TNL stage which feedsinto the above.
@@ -52,13 +52,13 @@ static GLboolean draw( GLcontext * ctx, struct tnl_pipeline_stage *stage )
struct st_context *st = st_context(ctx);
struct vertex_buffer *VB = &TNL_CONTEXT(ctx)->vb;
/* Validate driver and softpipe state:
*/
st_validate_state( st );
/* Call into the new draw code to handle the VB:
*/
- st->softpipe->draw_vb( st->softpipe, VB );
+ st->pipe->draw_vb( st->pipe, VB );
/* Finished
*/
@@ -84,7 +84,7 @@ static const struct tnl_pipeline_stage *intel_pipeline[] = {
&_tnl_texture_transform_stage,
&_tnl_point_attenuation_stage,
&_tnl_vertex_program_stage,
- &st_draw, /* ADD: escape to softpipe */
+ &st_draw, /* ADD: escape to pipe */
0,
};
@@ -52,13 +52,13 @@ static GLboolean draw( GLcontext * ctx, struct tnl_pipeline_stage *stage )
struct st_context *st = st_context(ctx);
struct vertex_buffer *VB = &TNL_CONTEXT(ctx)->vb;
- /* Validate driver and softpipe state:
+ /* Validate driver and pipe state:
*/
st_validate_state( st );